summaryrefslogtreecommitdiffstats
path: root/src/kvirc/ui/kvi_input.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:40:04 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:40:04 -0600
commitf91149819be7e7f45e68f22876f3c0062a11d4b9 (patch)
treeea2e0b384a225b9fcedd5ec44e08d1ad2fc2570b /src/kvirc/ui/kvi_input.cpp
parent32a249baaef1b910bffd79734c78cac3671f00f2 (diff)
downloadkvirc-f91149819be7e7f45e68f22876f3c0062a11d4b9.tar.gz
kvirc-f91149819be7e7f45e68f22876f3c0062a11d4b9.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'src/kvirc/ui/kvi_input.cpp')
-rw-r--r--src/kvirc/ui/kvi_input.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/kvirc/ui/kvi_input.cpp b/src/kvirc/ui/kvi_input.cpp
index 5445738..5d2e1c6 100644
--- a/src/kvirc/ui/kvi_input.cpp
+++ b/src/kvirc/ui/kvi_input.cpp
@@ -1325,7 +1325,7 @@ void KviInputEditor::imComposeEvent(TQIMEvent *e)
#endif
- // tqrepaint
+ // repaint
m_bUpdatesEnabled = true;
repaintWithCursorOn();
e->accept();
@@ -1347,7 +1347,7 @@ void KviInputEditor::imEndEvent(TQIMEvent *e)
// move cursor to after the IM result text
moveCursorTo(m_iIMStart + m_iIMLength);
- // tqrepaint
+ // repaint
m_bUpdatesEnabled = true;
repaintWithCursorOn();
@@ -2497,7 +2497,7 @@ void KviInput::keyPressEvent(TQKeyEvent *e)
"here to prevent you from accidentally sending<br>" \
"a really large message just because you didn't edit it<br>" \
"properly after pasting text from the clipboard.<br><br>" \
- "Do you want the message to be sent?").tqarg(nLines),
+ "Do you want the message to be sent?").arg(nLines),
__tr2qs("Yes, always"),
__tr2qs("Yes"),
__tr2qs("No"),
@@ -2543,7 +2543,7 @@ void KviInput::multilineEditorButtonToggled(bool bOn)
KviScriptEditor::destroyInstance(m_pMultiLineEditor);
m_pMultiLineEditor = 0;
m_pInputEditor->show();
- m_pWindow->tqchildrenTreeChanged(0);
+ m_pWindow->childrenTreeChanged(0);
m_pInputEditor->setFocus();
m_pMultiEditorButton->setOn(false);
} else {
@@ -2556,7 +2556,7 @@ void KviInput::multilineEditorButtonToggled(bool bOn)
m_pMultiLineEditor->setFindLineeditReadOnly(true);
m_pInputEditor->hide();
m_pMultiLineEditor->show();
- m_pWindow->tqchildrenTreeChanged(m_pMultiLineEditor);
+ m_pWindow->childrenTreeChanged(m_pMultiLineEditor);
m_pMultiLineEditor->setFocus();
m_pMultiEditorButton->setOn(true);
}
@@ -2596,14 +2596,14 @@ void KviInput::historyButtonClicked()
void KviInput::setFocus()
{
// redirect setFocus() to the right tqchildren
if(m_pMultiLineEditor)m_pMultiLineEditor->setFocus();
else m_pInputEditor->setFocus();
}
void KviInput::focusInEvent(TQFocusEvent * e)
{
- // if we get a focus in event , redirect the focus to the tqchildren
+ // if we get a focus in event , redirect the focus to the children
if(m_pMultiLineEditor)m_pMultiLineEditor->setFocus();
else m_pInputEditor->setFocus();
}
@@ -2596,14 +2596,14 @@ void KviInput::historyButtonClicked()
void KviInput::setFocus()
{
- // redirect setFocus() to the right tqchildren
+ // redirect setFocus() to the right children
if(m_pMultiLineEditor)m_pMultiLineEditor->setFocus();
else m_pInputEditor->setFocus();